pub struct ExtendedLocalizedString {
Show 17 fields pub en_gb: String, pub ko_kr: String, pub fr_fr: String, pub de_de: String, pub en_cn: String, pub en_tw: String, pub es_es: String, pub es_mx: String, pub ru_ru: String, pub ja_jp: String, pub pt_pt: String, pub it_it: String, pub unknown_12: String, pub unknown_13: String, pub unknown_14: String, pub unknown_15: String, pub flags: u32,
}
Available on crate features tbc or wrath only.
DBCs from the English version of the game will only have English version strings, while other localizations will have other languages.

You are most likely interested in, LocalizedString::en_gb, the English version.

Fields

en_gb: String

English, Great Britain

ko_kr: String

Korean, Korea

fr_fr: String

French, France

de_de: String

German, Germany

en_cn: String

English, China

en_tw: String

English, Taiwan

es_es: String

Spanish, Spain

es_mx: String

Spanish, Mexico

ru_ru: String

Russian, Russia

ja_jp: String

Japanese, Japan

pt_pt: String

Portuguese, Portugal

Also works as Portuguese, Brazil

it_it: String

Italian, Italy

unknown_12: String

Possibly unused.

unknown_13: String

Possibly unused.

unknown_14: String

Possibly unused.

unknown_15: String

Possibly unused.

flags: u32

Unknown flags.