Struct wow_dbc::tbc_tables::spell_visual::SpellVisual
source · [−]pub struct SpellVisual {
pub rows: Vec<SpellVisualRow>,
}Available on crate feature
tbc only.Fields
rows: Vec<SpellVisualRow>Trait Implementations
sourceimpl Clone for SpellVisual
impl Clone for SpellVisual
sourcefn clone(&self) -> SpellVisual
fn clone(&self) -> SpellVisual
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl DbcTable for SpellVisual
impl DbcTable for SpellVisual
type Row = SpellVisualRow
type Row = SpellVisualRow
Will be the name of the implementing type suffixed with
Row.sourceimpl Debug for SpellVisual
impl Debug for SpellVisual
sourceimpl Hash for SpellVisual
impl Hash for SpellVisual
sourceimpl Indexable for SpellVisual
impl Indexable for SpellVisual
type PrimaryKey = SpellVisualKey
type PrimaryKey = SpellVisualKey
Key used to index into the table. Same name as the table suffixed with
Key.sourcefn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourcefn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
fn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourceimpl Ord for SpellVisual
impl Ord for SpellVisual
sourcefn cmp(&self, other: &SpellVisual) -> Ordering
fn cmp(&self, other: &SpellVisual) -> Ordering
1.21.0 · sourceconst fn max(self, other: Self) -> Selfwhere
Self: Sized,
const fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 · sourceconst fn min(self, other: Self) -> Selfwhere
Self: Sized,
const fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
1.50.0 · sourceconst fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
const fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<SpellVisual> for SpellVisual
impl PartialEq<SpellVisual> for SpellVisual
sourcefn eq(&self, other: &SpellVisual) -> bool
fn eq(&self, other: &SpellVisual) -> bool
sourceimpl PartialOrd<SpellVisual> for SpellVisual
impl PartialOrd<SpellVisual> for SpellVisual
sourcefn partial_cmp(&self, other: &SpellVisual) -> Option<Ordering>
fn partial_cmp(&self, other: &SpellVisual) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for SpellVisual
impl StructuralEq for SpellVisual
impl StructuralPartialEq for SpellVisual