Struct wow_dbc::vanilla_tables::emotes_text_data::EmotesTextData
source · [−]pub struct EmotesTextData {
pub rows: Vec<EmotesTextDataRow>,
}Available on crate feature
vanilla only.Fields
rows: Vec<EmotesTextDataRow>Trait Implementations
sourceimpl Clone for EmotesTextData
impl Clone for EmotesTextData
sourcefn clone(&self) -> EmotesTextData
fn clone(&self) -> EmotesTextData
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl DbcTable for EmotesTextData
impl DbcTable for EmotesTextData
type Row = EmotesTextDataRow
type Row = EmotesTextDataRow
Will be the name of the implementing type suffixed with
Row.sourceimpl Debug for EmotesTextData
impl Debug for EmotesTextData
sourceimpl Hash for EmotesTextData
impl Hash for EmotesTextData
sourceimpl Indexable for EmotesTextData
impl Indexable for EmotesTextData
type PrimaryKey = EmotesTextDataKey
type PrimaryKey = EmotesTextDataKey
Key used to index into the table. Same name as the table suffixed with
Key.sourcefn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourcefn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
fn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourceimpl Ord for EmotesTextData
impl Ord for EmotesTextData
sourcefn cmp(&self, other: &EmotesTextData) -> Ordering
fn cmp(&self, other: &EmotesTextData) -> Ordering
1.21.0 · sourceconst fn max(self, other: Self) -> Selfwhere
Self: Sized,
const fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 · sourceconst fn min(self, other: Self) -> Selfwhere
Self: Sized,
const fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
1.50.0 · sourceconst fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
const fn clamp(self, min: Self, max: Self) -> Selfwhere
Self: Sized + PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialEq<EmotesTextData> for EmotesTextData
impl PartialEq<EmotesTextData> for EmotesTextData
sourcefn eq(&self, other: &EmotesTextData) -> bool
fn eq(&self, other: &EmotesTextData) -> bool
sourceimpl PartialOrd<EmotesTextData> for EmotesTextData
impl PartialOrd<EmotesTextData> for EmotesTextData
sourcefn partial_cmp(&self, other: &EmotesTextData) -> Option<Ordering>
fn partial_cmp(&self, other: &EmotesTextData) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for EmotesTextData
impl StructuralEq for EmotesTextData
impl StructuralPartialEq for EmotesTextData