Struct wow_dbc::wrath_tables::creature_model_data::CreatureModelData
source · [−]pub struct CreatureModelData {
pub rows: Vec<CreatureModelDataRow>,
}Available on crate feature
wrath only.Fields
rows: Vec<CreatureModelDataRow>Trait Implementations
sourceimpl Clone for CreatureModelData
impl Clone for CreatureModelData
sourcefn clone(&self) -> CreatureModelData
fn clone(&self) -> CreatureModelData
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl DbcTable for CreatureModelData
impl DbcTable for CreatureModelData
type Row = CreatureModelDataRow
type Row = CreatureModelDataRow
Will be the name of the implementing type suffixed with
Row.sourceimpl Debug for CreatureModelData
impl Debug for CreatureModelData
sourceimpl Indexable for CreatureModelData
impl Indexable for CreatureModelData
type PrimaryKey = CreatureModelDataKey
type PrimaryKey = CreatureModelDataKey
Key used to index into the table. Same name as the table suffixed with
Key.sourcefn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourcefn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
fn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourceimpl PartialEq<CreatureModelData> for CreatureModelData
impl PartialEq<CreatureModelData> for CreatureModelData
sourcefn eq(&self, other: &CreatureModelData) -> bool
fn eq(&self, other: &CreatureModelData) -> bool
sourceimpl PartialOrd<CreatureModelData> for CreatureModelData
impl PartialOrd<CreatureModelData> for CreatureModelData
sourcefn partial_cmp(&self, other: &CreatureModelData) -> Option<Ordering>
fn partial_cmp(&self, other: &CreatureModelData) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl StructuralPartialEq for CreatureModelData