Available on crate feature
wrath only.Fields
rows: Vec<MapRow>Trait Implementations
sourceimpl DbcTable for Map
impl DbcTable for Map
sourceimpl Indexable for Map
impl Indexable for Map
type PrimaryKey = MapKey
type PrimaryKey = MapKey
Key used to index into the table. Same name as the table suffixed with
Key.sourcefn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl Into<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourcefn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
fn get_mut(&mut self, key: impl Into<Self::PrimaryKey>) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present. Read moresourceimpl PartialOrd<Map> for Map
impl PartialOrd<Map> for Map
sourcefn partial_cmp(&self, other: &Map) -> Option<Ordering>
fn partial_cmp(&self, other: &Map) -> Option<Ordering>
1.0.0 · sourceconst fn le(&self, other: &Rhs) -> bool
const fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl StructuralPartialEq for Map