pub struct ObjectEffect {
pub rows: Vec<ObjectEffectRow>,
}Available on crate feature
wrath only.Fields
rows: Vec<ObjectEffectRow>Trait Implementations
Sourceimpl Clone for ObjectEffect
impl Clone for ObjectEffect
Sourcefn clone(&self) -> ObjectEffect
fn clone(&self) -> ObjectEffect
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DbcTable for ObjectEffect
impl DbcTable for ObjectEffect
Sourceconst FILENAME: &'static str = "ObjectEffect.dbc"
const FILENAME: &'static str = "ObjectEffect.dbc"
The name of the DBC file with
.dbc at the end.Sourcetype Row = ObjectEffectRow
type Row = ObjectEffectRow
Will be the name of the implementing type suffixed with
Row.Sourceimpl Debug for ObjectEffect
impl Debug for ObjectEffect
Sourceimpl Indexable for ObjectEffect
impl Indexable for ObjectEffect
Sourcetype PrimaryKey = ObjectEffectKey
type PrimaryKey = ObjectEffectKey
Key used to index into the table. Same name as the table suffixed with
Key.Sourcefn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourcefn get_mut(
&mut self,
key: impl TryInto<Self::PrimaryKey>,
) -> Option<&mut Self::Row>
fn get_mut( &mut self, key: impl TryInto<Self::PrimaryKey>, ) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourceimpl PartialEq for ObjectEffect
impl PartialEq for ObjectEffect
Sourceimpl PartialOrd for ObjectEffect
impl PartialOrd for ObjectEffect
impl StructuralPartialEq for ObjectEffect