pub struct SpellVisualKitModelAttach {
pub rows: Vec<SpellVisualKitModelAttachRow>,
}Available on crate feature
wrath only.Fields
rows: Vec<SpellVisualKitModelAttachRow>Trait Implementations
Sourceimpl Clone for SpellVisualKitModelAttach
impl Clone for SpellVisualKitModelAttach
Sourcefn clone(&self) -> SpellVisualKitModelAttach
fn clone(&self) -> SpellVisualKitModelAttach
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DbcTable for SpellVisualKitModelAttach
impl DbcTable for SpellVisualKitModelAttach
Sourceconst FILENAME: &'static str = "SpellVisualKitModelAttach.dbc"
const FILENAME: &'static str = "SpellVisualKitModelAttach.dbc"
The name of the DBC file with
.dbc at the end.Sourcetype Row = SpellVisualKitModelAttachRow
type Row = SpellVisualKitModelAttachRow
Will be the name of the implementing type suffixed with
Row.Sourceimpl Debug for SpellVisualKitModelAttach
impl Debug for SpellVisualKitModelAttach
Sourceimpl Indexable for SpellVisualKitModelAttach
impl Indexable for SpellVisualKitModelAttach
Sourcetype PrimaryKey = SpellVisualKitModelAttachKey
type PrimaryKey = SpellVisualKitModelAttachKey
Key used to index into the table. Same name as the table suffixed with
Key.Sourcefn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourcefn get_mut(
&mut self,
key: impl TryInto<Self::PrimaryKey>,
) -> Option<&mut Self::Row>
fn get_mut( &mut self, key: impl TryInto<Self::PrimaryKey>, ) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourceimpl PartialOrd for SpellVisualKitModelAttach
impl PartialOrd for SpellVisualKitModelAttach
impl StructuralPartialEq for SpellVisualKitModelAttach