pub struct StringLookups {
pub rows: Vec<StringLookupsRow>,
}Available on crate feature
wrath only.Fields
rows: Vec<StringLookupsRow>Trait Implementations
Sourceimpl Clone for StringLookups
impl Clone for StringLookups
Sourcefn clone(&self) -> StringLookups
fn clone(&self) -> StringLookups
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DbcTable for StringLookups
impl DbcTable for StringLookups
Sourceconst FILENAME: &'static str = "StringLookups.dbc"
const FILENAME: &'static str = "StringLookups.dbc"
The name of the DBC file with
.dbc at the end.Sourcetype Row = StringLookupsRow
type Row = StringLookupsRow
Will be the name of the implementing type suffixed with
Row.Sourceimpl Debug for StringLookups
impl Debug for StringLookups
Sourceimpl Hash for StringLookups
impl Hash for StringLookups
Sourceimpl Indexable for StringLookups
impl Indexable for StringLookups
Sourcetype PrimaryKey = StringLookupsKey
type PrimaryKey = StringLookupsKey
Key used to index into the table. Same name as the table suffixed with
Key.Sourcefn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
fn get(&self, key: impl TryInto<Self::PrimaryKey>) -> Option<&Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourcefn get_mut(
&mut self,
key: impl TryInto<Self::PrimaryKey>,
) -> Option<&mut Self::Row>
fn get_mut( &mut self, key: impl TryInto<Self::PrimaryKey>, ) -> Option<&mut Self::Row>
Gets the primary key, if present. Internally this is just
std::iter::Iterator::find since the
items are not guaranteed to be ordered nor even be present.Sourceimpl Ord for StringLookups
impl Ord for StringLookups
Sourcefn cmp(&self, other: &StringLookups) -> Ordering
fn cmp(&self, other: &StringLookups) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringLookups
impl PartialEq for StringLookups
Sourceimpl PartialOrd for StringLookups
impl PartialOrd for StringLookups
impl Eq for StringLookups
impl StructuralPartialEq for StringLookups