Struct wow_dbc::ExtendedLocalizedString
source · [−]pub struct ExtendedLocalizedString {Show 17 fields
pub en_gb: String,
pub ko_kr: String,
pub fr_fr: String,
pub de_de: String,
pub en_cn: String,
pub en_tw: String,
pub es_es: String,
pub es_mx: String,
pub ru_ru: String,
pub ja_jp: String,
pub pt_pt: String,
pub it_it: String,
pub unknown_12: String,
pub unknown_13: String,
pub unknown_14: String,
pub unknown_15: String,
pub flags: u32,
}Available on crate features
tbc or wrath only.Expand description
DBCs from the English version of the game will only have English version strings, while other localizations will have other languages.
You are most likely interested in, LocalizedString::en_gb, the English version.
Fields
en_gb: StringEnglish, Great Britain
ko_kr: StringKorean, Korea
fr_fr: StringFrench, France
de_de: StringGerman, Germany
en_cn: StringEnglish, China
en_tw: StringEnglish, Taiwan
es_es: StringSpanish, Spain
es_mx: StringSpanish, Mexico
ru_ru: StringRussian, Russia
ja_jp: StringJapanese, Japan
pt_pt: StringPortuguese, Portugal
Also works as Portuguese, Brazil
it_it: StringItalian, Italy
unknown_12: StringPossibly unused.
unknown_13: StringPossibly unused.
unknown_14: StringPossibly unused.
unknown_15: StringPossibly unused.
flags: u32Unknown flags.